==> haskell-skylighting-format-latex-0.1-116-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-F9YhMzIZACX5NF2AMw3Tkv
key:                  skylighting-format-latex-0.1-F9YhMzIZACX5NF2AMw3Tkv
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  754c77a0efa77aa9b4276f35df7c8c0a
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-F9YhMzIZACX5NF2AMw3Tkv
depends:
    base-4.16.4.0 containers-0.6.5.1
    skylighting-core-0.14-BzqlWbZbHEV8cQATNhXW5s text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-latex-0.1-117-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-CQtDCRxbVFDH70mUKu0qba
key:                  skylighting-format-latex-0.1-CQtDCRxbVFDH70mUKu0qba
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  b5d3800f537c595cafc443aeb727ee15
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-CQtDCRxbVFDH70mUKu0qba
depends:
    base-4.16.4.0 containers-0.6.5.1
    skylighting-core-0.14-G627Fh4sueu1RyTRIOQ6ye text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
